==> servicecatalog-model-6.8.1-sources.jar: io/fabric8/servicecatalog/api/model/SecretTransformFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SecretTransformFluent<A extends SecretTransformFluent<A>> extends BaseFluent<A>{
  public SecretTransformFluent() {
  }
  public SecretTransformFluent(SecretTransform instance) {
    instance = (instance != null ? instance : new SecretTransform());

    if (instance != null) {
      this.withAddKey(instance.getAddKey());
      this.withAddKeysFrom(instance.getAddKeysFrom());
      this.withRemoveKey(instance.getRemoveKey());
      this.withRenameKey(instance.getRenameKey());
      this.withAddKey(instance.getAddKey());
      this.withAddKeysFrom(instance.getAddKeysFrom());
      this.withRemoveKey(instance.getRemoveKey());
      this.withRenameKey(instance.getRenameKey());
    }
  }
  private AddKeyTransformBuilder addKey;
  private AddKeysFromTransformBuilder addKeysFrom;
  private RemoveKeyTransformBuilder removeKey;
  private RenameKeyTransformBuilder renameKey;
  public AddKeyTransform buildAddKey() {
    return this.addKey!=null ?this.addKey.build():null;
  }
  public A withAddKey(AddKeyTransform addKey) {
    _visitables.get("addKey").remove(this.addKey);
    if (addKey!=null){ this.addKey= new AddKeyTransformBuilder(addKey); _visitables.get("addKey").add(this.addKey);} else { this.addKey = null; _visitables.get("addKey").remove(this.addKey); } return (A) this;
  }
  public boolean hasAddKey() {
    return this.addKey != null;
  }
  public A withNewAddKey(String jsonPathExpression,String key,String stringValue,String value) {
    return (A)withAddKey(new AddKeyTransform(jsonPathExpression, key, stringValue, value));
  }
  public AddKeyNested<A> withNewAddKey() {
    return new AddKeyNested(null);
  }
  public AddKeyNested<A> withNewAddKeyLike(AddKeyTransform item) {
    return new AddKeyNested(item);
  }
  public AddKeyNested<A> editAddKey() {
    return withNewAddKeyLike(java.util.Optional.ofNullable(buildAddKey()).orElse(null));
  }
  public AddKeyNested<A> editOrNewAddKey() {
    return withNewAddKeyLike(java.util.Optional.ofNullable(buildAddKey()).orElse(new AddKeyTransformBuilder().build()));
  }
  public AddKeyNested<A> editOrNewAddKeyLike(AddKeyTransform item) {
    return withNewAddKeyLike(java.util.Optional.ofNullable(buildAddKey()).orElse(item));
  }
  public AddKeysFromTransform buildAddKeysFrom() {
    return this.addKeysFrom!=null ?this.addKeysFrom.build():null;
  }
  public A withAddKeysFrom(AddKeysFromTransform addKeysFrom) {
    _visitables.get("addKeysFrom").remove(this.addKeysFrom);
    if (addKeysFrom!=null){ this.addKeysFrom= new AddKeysFromTransformBuilder(addKeysFrom); _visitables.get("addKeysFrom").add(this.addKeysFrom);} else { this.addKeysFrom = null; _visitables.get("addKeysFrom").remove(this.addKeysFrom); } return (A) this;
  }
  public boolean hasAddKeysFrom() {
    return this.addKeysFrom != null;
  }
  public AddKeysFromNested<A> withNewAddKeysFrom() {
    return new AddKeysFromNested(null);
  }
  public AddKeysFromNested<A> withNewAddKeysFromLike(AddKeysFromTransform item) {
    return new AddKeysFromNested(item);
  }
  public AddKeysFromNested<A> editAddKeysFrom() {
    return withNewAddKeysFromLike(java.util.Optional.ofNullable(buildAddKeysFrom()).orElse(null));
  }
  public AddKeysFromNested<A> editOrNewAddKeysFrom() {
    return withNewAddKeysFromLike(java.util.Optional.ofNullable(buildAddKeysFrom()).orElse(new AddKeysFromTransformBuilder().build()));
  }
  public AddKeysFromNested<A> editOrNewAddKeysFromLike(AddKeysFromTransform item) {
    return withNewAddKeysFromLike(java.util.Optional.ofNullable(buildAddKeysFrom()).orElse(item));
  }
  public RemoveKeyTransform buildRemoveKey() {
    return this.removeKey!=null ?this.removeKey.build():null;
  }
  public A withRemoveKey(RemoveKeyTransform removeKey) {
    _visitables.get("removeKey").remove(this.removeKey);
    if (removeKey!=null){ this.removeKey= new RemoveKeyTransformBuilder(removeKey); _visitables.get("removeKey").add(this.removeKey);} else { this.removeKey = null; _visitables.get("removeKey").remove(this.removeKey); } return (A) this;
  }
  public boolean hasRemoveKey() {
    return this.removeKey != null;
  }
  public A withNewRemoveKey(String key) {
    return (A)withRemoveKey(new RemoveKeyTransform(key));
  }
  public RemoveKeyNested<A> withNewRemoveKey() {
    return new RemoveKeyNested(null);
  }
  public RemoveKeyNested<A> withNewRemoveKeyLike(RemoveKeyTransform item) {
    return new RemoveKeyNested(item);
  }
  public RemoveKeyNested<A> editRemoveKey() {
    return withNewRemoveKeyLike(java.util.Optional.ofNullable(buildRemoveKey()).orElse(null));
  }
  public RemoveKeyNested<A> editOrNewRemoveKey() {
    return withNewRemoveKeyLike(java.util.Optional.ofNullable(buildRemoveKey()).orElse(new RemoveKeyTransformBuilder().build()));
  }
  public RemoveKeyNested<A> editOrNewRemoveKeyLike(RemoveKeyTransform item) {
    return withNewRemoveKeyLike(java.util.Optional.ofNullable(buildRemoveKey()).orElse(item));
  }
  public RenameKeyTransform buildRenameKey() {
    return this.renameKey!=null ?this.renameKey.build():null;
  }
  public A withRenameKey(RenameKeyTransform renameKey) {
    _visitables.get("renameKey").remove(this.renameKey);
    if (renameKey!=null){ this.renameKey= new RenameKeyTransformBuilder(renameKey); _visitables.get("renameKey").add(this.renameKey);} else { this.renameKey = null; _visitables.get("renameKey").remove(this.renameKey); } return (A) this;
  }
  public boolean hasRenameKey() {
    return this.renameKey != null;
  }
  public A withNewRenameKey(String from,String to) {
    return (A)withRenameKey(new RenameKeyTransform(from, to));
  }
  public RenameKeyNested<A> withNewRenameKey() {
    return new RenameKeyNested(null);
  }
  public RenameKeyNested<A> withNewRenameKeyLike(RenameKeyTransform item) {
    return new RenameKeyNested(item);
  }
  public RenameKeyNested<A> editRenameKey() {
    return withNewRenameKeyLike(java.util.Optional.ofNullable(buildRenameKey()).orElse(null));
  }
  public RenameKeyNested<A> editOrNewRenameKey() {
    return withNewRenameKeyLike(java.util.Optional.ofNullable(buildRenameKey()).orElse(new RenameKeyTransformBuilder().build()));
  }
  public RenameKeyNested<A> editOrNewRenameKeyLike(RenameKeyTransform item) {
    return withNewRenameKeyLike(java.util.Optional.ofNullable(buildRenameKey()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretTransformFluent that = (SecretTransformFluent) o;
    if (!java.util.Objects.equals(addKey, that.addKey)) return false;

    if (!java.util.Objects.equals(addKeysFrom, that.addKeysFrom)) return false;

    if (!java.util.Objects.equals(removeKey, that.removeKey)) return false;

    if (!java.util.Objects.equals(renameKey, that.renameKey)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(addKey,  addKeysFrom,  removeKey,  renameKey,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (addKey != null) { sb.append("addKey:"); sb.append(addKey + ","); }
    if (addKeysFrom != null) { sb.append("addKeysFrom:"); sb.append(addKeysFrom + ","); }
    if (removeKey != null) { sb.append("removeKey:"); sb.append(removeKey + ","); }
    if (renameKey != null) { sb.append("renameKey:"); sb.append(renameKey); }
    sb.append("}");
    return sb.toString();
  }
  public class AddKeyNested<N> extends AddKeyTransformFluent<AddKeyNested<N>> implements Nested<N>{
    AddKeyNested(AddKeyTransform item) {
      this.builder = new AddKeyTransformBuilder(this, item);
    }
    AddKeyTransformBuilder builder;
    public N and() {
      return (N) SecretTransformFluent.this.withAddKey(builder.build());
    }
    public N endAddKey() {
      return and();
    }
    
  }
  public class AddKeysFromNested<N> extends AddKeysFromTransformFluent<AddKeysFromNested<N>> implements Nested<N>{
    AddKeysFromNested(AddKeysFromTransform item) {
      this.builder = new AddKeysFromTransformBuilder(this, item);
    }
    AddKeysFromTransformBuilder builder;
    public N and() {
      return (N) SecretTransformFluent.this.withAddKeysFrom(builder.build());
    }
    public N endAddKeysFrom() {
      return and();
    }
    
  }
  public class RemoveKeyNested<N> extends RemoveKeyTransformFluent<RemoveKeyNested<N>> implements Nested<N>{
    RemoveKeyNested(RemoveKeyTransform item) {
      this.builder = new RemoveKeyTransformBuilder(this, item);
    }
    RemoveKeyTransformBuilder builder;
    public N and() {
      return (N) SecretTransformFluent.this.withRemoveKey(builder.build());
    }
    public N endRemoveKey() {
      return and();
    }
    
  }
  public class RenameKeyNested<N> extends RenameKeyTransformFluent<RenameKeyNested<N>> implements Nested<N>{
    RenameKeyNested(RenameKeyTransform item) {
      this.builder = new RenameKeyTransformBuilder(this, item);
    }
    RenameKeyTransformBuilder builder;
    public N and() {
      return (N) SecretTransformFluent.this.withRenameKey(builder.build());
    }
    public N endRenameKey() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/SecretTransformFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SecretTransformFluent<A extends SecretTransformFluent<A>> extends BaseFluent<A>{
  public SecretTransformFluent() {
  }
  
  public SecretTransformFluent(SecretTransform instance) {
    this.copyInstance(instance);
  }
  private AddKeyTransformBuilder addKey;
  private AddKeysFromTransformBuilder addKeysFrom;
  private RemoveKeyTransformBuilder removeKey;
  private RenameKeyTransformBuilder renameKey;
  
  protected void copyInstance(SecretTransform instance) {
    instance = (instance != null ? instance : new SecretTransform());
  
    if (instance != null) {
        this.withAddKey(instance.getAddKey());
        this.withAddKeysFrom(instance.getAddKeysFrom());
        this.withRemoveKey(instance.getRemoveKey());
        this.withRenameKey(instance.getRenameKey());
        this.withAddKey(instance.getAddKey());
        this.withAddKeysFrom(instance.getAddKeysFrom());
        this.withRemoveKey(instance.getRemoveKey());
        this.withRenameKey(instance.getRenameKey());
      }
  }
  
  public AddKeyTransform buildAddKey() {
    return this.addKey!=null ?this.addKey.build():null;
  }
  
  public A withAddKey(AddKeyTransform addKey) {
    _visitables.get("addKey").remove(this.addKey);
    if (addKey!=null){ this.addKey= new AddKeyTransformBuilder(addKey); _visitables.get("addKey").add(this.addKey);} else { this.addKey = null; _visitables.get("addKey").remove(this.addKey); } return (A) this;
  }
  
  public boolean hasAddKey() {
    return this.addKey != null;
  }
  
  public A withNewAddKey(String jsonPathExpression,String key,String stringValue,String value) {
    return (A)withAddKey(new AddKeyTransform(jsonPathExpression, key, stringValue, value));
  }
  
  public AddKeyNested<A> withNewAddKey() {
    return new AddKeyNested(null);
  }
  
  public AddKeyNested<A> withNewAddKeyLike(AddKeyTransform item) {
    return new AddKeyNested(item);
  }
  
  public AddKeyNested<A> editAddKey() {
    return withNewAddKeyLike(java.util.Optional.ofNullable(buildAddKey()).orElse(null));
  }
  
  public AddKeyNested<A> editOrNewAddKey() {
    return withNewAddKeyLike(java.util.Optional.ofNullable(buildAddKey()).orElse(new AddKeyTransformBuilder().build()));
  }
  
  public AddKeyNested<A> editOrNewAddKeyLike(AddKeyTransform item) {
    return withNewAddKeyLike(java.util.Optional.ofNullable(buildAddKey()).orElse(item));
  }
  
  public AddKeysFromTransform buildAddKeysFrom() {
    return this.addKeysFrom!=null ?this.addKeysFrom.build():null;
  }
  
  public A withAddKeysFrom(AddKeysFromTransform addKeysFrom) {
    _visitables.get("addKeysFrom").remove(this.addKeysFrom);
    if (addKeysFrom!=null){ this.addKeysFrom= new AddKeysFromTransformBuilder(addKeysFrom); _visitables.get("addKeysFrom").add(this.addKeysFrom);} else { this.addKeysFrom = null; _visitables.get("addKeysFrom").remove(this.addKeysFrom); } return (A) this;
  }
  
  public boolean hasAddKeysFrom() {
    return this.addKeysFrom != null;
  }
  
  public AddKeysFromNested<A> withNewAddKeysFrom() {
    return new AddKeysFromNested(null);
  }
  
  public AddKeysFromNested<A> withNewAddKeysFromLike(AddKeysFromTransform item) {
    return new AddKeysFromNested(item);
  }
  
  public AddKeysFromNested<A> editAddKeysFrom() {
    return withNewAddKeysFromLike(java.util.Optional.ofNullable(buildAddKeysFrom()).orElse(null));
  }
  
  public AddKeysFromNested<A> editOrNewAddKeysFrom() {
    return withNewAddKeysFromLike(java.util.Optional.ofNullable(buildAddKeysFrom()).orElse(new AddKeysFromTransformBuilder().build()));
  }
  
  public AddKeysFromNested<A> editOrNewAddKeysFromLike(AddKeysFromTransform item) {
    return withNewAddKeysFromLike(java.util.Optional.ofNullable(buildAddKeysFrom()).orElse(item));
  }
  
  public RemoveKeyTransform buildRemoveKey() {
    return this.removeKey!=null ?this.removeKey.build():null;
  }
  
  public A withRemoveKey(RemoveKeyTransform removeKey) {
    _visitables.get("removeKey").remove(this.removeKey);
    if (removeKey!=null){ this.removeKey= new RemoveKeyTransformBuilder(removeKey); _visitables.get("removeKey").add(this.removeKey);} else { this.removeKey = null; _visitables.get("removeKey").remove(this.removeKey); } return (A) this;
  }
  
  public boolean hasRemoveKey() {
    return this.removeKey != null;
  }
  
  public A withNewRemoveKey(String key) {
    return (A)withRemoveKey(new RemoveKeyTransform(key));
  }
  
  public RemoveKeyNested<A> withNewRemoveKey() {
    return new RemoveKeyNested(null);
  }
  
  public RemoveKeyNested<A> withNewRemoveKeyLike(RemoveKeyTransform item) {
    return new RemoveKeyNested(item);
  }
  
  public RemoveKeyNested<A> editRemoveKey() {
    return withNewRemoveKeyLike(java.util.Optional.ofNullable(buildRemoveKey()).orElse(null));
  }
  
  public RemoveKeyNested<A> editOrNewRemoveKey() {
    return withNewRemoveKeyLike(java.util.Optional.ofNullable(buildRemoveKey()).orElse(new RemoveKeyTransformBuilder().build()));
  }
  
  public RemoveKeyNested<A> editOrNewRemoveKeyLike(RemoveKeyTransform item) {
    return withNewRemoveKeyLike(java.util.Optional.ofNullable(buildRemoveKey()).orElse(item));
  }
  
  public RenameKeyTransform buildRenameKey() {
    return this.renameKey!=null ?this.renameKey.build():null;
  }
  
  public A withRenameKey(RenameKeyTransform renameKey) {
    _visitables.get("renameKey").remove(this.renameKey);
    if (renameKey!=null){ this.renameKey= new RenameKeyTransformBuilder(renameKey); _visitables.get("renameKey").add(this.renameKey);} else { this.renameKey = null; _visitables.get("renameKey").remove(this.renameKey); } return (A) this;
  }
  
  public boolean hasRenameKey() {
    return this.renameKey != null;
  }
  
  public A withNewRenameKey(String from,String to) {
    return (A)withRenameKey(new RenameKeyTransform(from, to));
  }
  
  public RenameKeyNested<A> withNewRenameKey() {
    return new RenameKeyNested(null);
  }
  
  public RenameKeyNested<A> withNewRenameKeyLike(RenameKeyTransform item) {
    return new RenameKeyNested(item);
  }
  
  public RenameKeyNested<A> editRenameKey() {
    return withNewRenameKeyLike(java.util.Optional.ofNullable(buildRenameKey()).orElse(null));
  }
  
  public RenameKeyNested<A> editOrNewRenameKey() {
    return withNewRenameKeyLike(java.util.Optional.ofNullable(buildRenameKey()).orElse(new RenameKeyTransformBuilder().build()));
  }
  
  public RenameKeyNested<A> editOrNewRenameKeyLike(RenameKeyTransform item) {
    return withNewRenameKeyLike(java.util.Optional.ofNullable(buildRenameKey()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretTransformFluent that = (SecretTransformFluent) o;
    if (!java.util.Objects.equals(addKey, that.addKey)) return false;
  
    if (!java.util.Objects.equals(addKeysFrom, that.addKeysFrom)) return false;
  
    if (!java.util.Objects.equals(removeKey, that.removeKey)) return false;
  
    if (!java.util.Objects.equals(renameKey, that.renameKey)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(addKey,  addKeysFrom,  removeKey,  renameKey,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (addKey != null) { sb.append("addKey:"); sb.append(addKey + ","); }
    if (addKeysFrom != null) { sb.append("addKeysFrom:"); sb.append(addKeysFrom + ","); }
    if (removeKey != null) { sb.append("removeKey:"); sb.append(removeKey + ","); }
    if (renameKey != null) { sb.append("renameKey:"); sb.append(renameKey); }
    sb.append("}");
    return sb.toString();
  }
  public class AddKeyNested<N> extends AddKeyTransformFluent<AddKeyNested<N>> implements Nested<N>{
    AddKeyNested(AddKeyTransform item) {
      this.builder = new AddKeyTransformBuilder(this, item);
    }
    AddKeyTransformBuilder builder;
    
    public N and() {
      return (N) SecretTransformFluent.this.withAddKey(builder.build());
    }
    
    public N endAddKey() {
      return and();
    }
    
  
  }
  public class AddKeysFromNested<N> extends AddKeysFromTransformFluent<AddKeysFromNested<N>> implements Nested<N>{
    AddKeysFromNested(AddKeysFromTransform item) {
      this.builder = new AddKeysFromTransformBuilder(this, item);
    }
    AddKeysFromTransformBuilder builder;
    
    public N and() {
      return (N) SecretTransformFluent.this.withAddKeysFrom(builder.build());
    }
    
    public N endAddKeysFrom() {
      return and();
    }
    
  
  }
  public class RemoveKeyNested<N> extends RemoveKeyTransformFluent<RemoveKeyNested<N>> implements Nested<N>{
    RemoveKeyNested(RemoveKeyTransform item) {
      this.builder = new RemoveKeyTransformBuilder(this, item);
    }
    RemoveKeyTransformBuilder builder;
    
    public N and() {
      return (N) SecretTransformFluent.this.withRemoveKey(builder.build());
    }
    
    public N endRemoveKey() {
      return and();
    }
    
  
  }
  public class RenameKeyNested<N> extends RenameKeyTransformFluent<RenameKeyNested<N>> implements Nested<N>{
    RenameKeyNested(RenameKeyTransform item) {
      this.builder = new RenameKeyTransformBuilder(this, item);
    }
    RenameKeyTransformBuilder builder;
    
    public N and() {
      return (N) SecretTransformFluent.this.withRenameKey(builder.build());
    }
    
    public N endRenameKey() {
      return and();
    }
    
  
  }

}
